@@ -17,7 +17,7 @@ from collections import OrderedDict
 from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
@@ -342,7 +342,7 @@ class AuthorizedDomainsClient(metaclass=AuthorizedDomainsClientMeta):
 
     def list_authorized_domains(
         self,
-        request: appengine.ListAuthorizedDomainsRequest = None,
+        request: Union[appengine.ListAuthorizedDomainsRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -352,7 +352,7 @@ class AuthorizedDomainsClient(metaclass=AuthorizedDomainsClientMeta):
         administer.
 
         Args:
-            request (google.cloud.appengine_admin_v1.types.ListAuthorizedDomainsRequest):
+            request (Union[google.cloud.appengine_admin_v1.types.ListAuthorizedDomainsRequest, dict]):
                 The request object. Request message for
                 `AuthorizedDomains.ListAuthorizedDomains`.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
